==> cscec5b-dataexchange-api-3.0.1-20231207.083838-92-sources.jar: com/ejianc/business/dataexchange/hystrix/CmContractInfoHystrix.java <==
package com.ejianc.business.dataexchange.hystrix;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.ejianc.business.dataexchange.api.ICmContractInfoApi;
import com.ejianc.business.dataexchange.vo.CmContractInfoVO;
import com.ejianc.business.dataexchange.vo.LeaseInfoPriceRecordVO;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.stereotype.Component;

import java.util.List;

/**
 * 模块hystrix
 *
 * @author sunq
 *
 */
@Component
public class CmContractInfoHystrix implements ICmContractInfoApi {

	@Override
	public CommonResponse<IPage<CmContractInfoVO>> querySubCmContractInfoRef(String pkContract,
																		 Integer pageNumber,
																		 Integer pageSize,
																		 String condition,
																		 String searchText) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<IPage<CmContractInfoVO>> queryMatContractInfoRef(String pkContract,
																		 Integer pageNumber,
																		 Integer pageSize,
																		 String condition,
																		 String searchText) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<List<CmContractInfoVO>> queryLeaseContractInfoById(String pkContract) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<List<CmContractInfoVO>> queryMatContractInfoById(String pkContract) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<List<LeaseInfoPriceRecordVO>> queryLeasePriceById(String pkContract, String pkContractInfo) {
		return CommonResponse.error("网络问题， 查询失败。");
	}


}

==> cscec5b-dataexchange-api-3.0.1-20250104.101829-109-sources.jar: com/ejianc/business/dataexchange/hystrix/CmContractInfoHystrix.java <==
package com.ejianc.business.dataexchange.hystrix;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.ejianc.business.dataexchange.api.ICmContractInfoApi;
import com.ejianc.business.dataexchange.vo.CmContractInfoVO;
import com.ejianc.business.dataexchange.vo.LeaseInfoPriceRecordVO;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.stereotype.Component;

import java.util.List;

/**
 * 模块hystrix
 *
 * @author sunq
 *
 */
@Component
public class CmContractInfoHystrix implements ICmContractInfoApi {

	@Override
	public CommonResponse<IPage<CmContractInfoVO>> querySubCmContractInfoRef(String pkContract,
																		 Integer pageNumber,
																		 Integer pageSize,
																		 String condition,
																		 String searchText) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<IPage<CmContractInfoVO>> queryMatContractInfoRef(String pkContract,
																		 Integer pageNumber,
																		 Integer pageSize,
																		 String condition,
																		 String searchText) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<List<CmContractInfoVO>> queryLeaseContractInfoById(String pkContract) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<List<CmContractInfoVO>> queryMatContractInfoById(String pkContract) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<List<LeaseInfoPriceRecordVO>> queryLeasePriceById(String pkContract, String pkContractInfo) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<List<CmContractInfoVO>> queryLeaseContractInfoByIdList(List<String> contractIdList) {
		return CommonResponse.error("网络问题， 查询失败。");
	}


}
